Apply Excel-style theme to an existing gt table
Arguments
- gt_object
An existing gt table object of class
gt_tbl- ...
Additional arguments passed to
gt::tab_options()- color
A string indicating the color of the row striping, defaults to a light gray Accepts either named colors or hex colors.